import type { NangoConnection } from '../models/Connection.js';
import type { Config as ProviderConfig } from '../models/Provider.js';
import type { NangoIntegrationData } from '../models/NangoConfig.js';
import { Sync, SyncCommand, SyncWithSchedule } from '../models/Sync.js';
import type { ServiceResponse } from '../models/Generic.js';
import { NangoError } from '../utils/error.js';
import { type Result } from '../utils/result.js';
declare class SyncClient {
    private static instance;
    private client;
    private namespace;
    private constructor();
    static getInstance(): Promise<SyncClient | null>;
    private static create;
    initiate(nangoConnectionId: number): Promise<void>;
    /**
     * Start Continuous
     * @desc get the connection information and the provider information
     * and kick off an initial sync and also a incremental sync. Also look
     * up any sync configs to call any integration snippet that was setup
     */
    startContinuous(nangoConnection: NangoConnection, sync: Sync, syncConfig: ProviderConfig, syncName: string, syncData: NangoIntegrationData, debug?: boolean): Promise<void>;
    deleteSyncSchedule(id: string, environmentId: number): Promise<boolean>;
    describeSchedule(schedule_id: string): Promise<false | import("@temporalio/proto").temporal.api.workflowservice.v1.DescribeScheduleResponse | undefined>;
    formatFutureRun(nextRun: number): Date | string;
    listSchedules(): Promise<import("@temporalio/proto").temporal.api.workflowservice.v1.ListSchedulesResponse | undefined>;
    runSyncCommand(scheduleId: string, syncId: string, command: SyncCommand, activityLogId: number, environmentId: number, providerConfigKey: string, connectionId: string, syncName: string, nangoConnectionId?: number): Promise<Result<boolean>>;
    cancelSync(syncId: string): Promise<Result<boolean>>;
    triggerSyncs(syncs: SyncWithSchedule[], environmentId: number): Promise<void>;
    triggerAction<T = any>(connection: NangoConnection, actionName: string, input: object, activityLogId: number, environment_id: number, writeLogs?: boolean): Promise<Result<T, NangoError>>;
    triggerWebhook<T = any>(nangoConnection: NangoConnection, webhookName: string, provider: string, parentSyncName: string, input: object, environment_id: number): Promise<ServiceResponse<T>>;
    updateSyncSchedule(schedule_id: string, interval: string, offset: number, environmentId: number, syncName?: string, activityLogId?: number): Promise<void>;
    triggerInitialSync({ syncId, jobId, syncName, nangoConnection, debug }: {
        syncId: string;
        jobId?: string;
        syncName: string;
        activityLogId: number;
        nangoConnection: NangoConnection;
        debug?: boolean;
    }): Promise<boolean>;
}
export default SyncClient;
