import { expect, describe, it, beforeAll } from 'vitest';
import { multipleMigrations } from '../db/database.js';
import connectionService from './connection.service.js';
import { createConfigSeeds } from '../db/seeders/config.seeder.js';
import { createConnectionSeeds } from '../db/seeders/connection.seeder.js';
describe('Connection service integration tests', () => {
    beforeAll(async () => {
        await multipleMigrations();
        await createConfigSeeds();
    });
    describe('Metadata simple operations', () => {
        it('Should replace existing metadata, overwriting anything existing', async () => {
            const connections = await createConnectionSeeds();
            const initialMetadata = {
                name: 'test',
                host: 'test'
            };
            const newMetadata = {
                additionalName: 'test23'
            };
            const [connectionId] = connections;
            const connection = { id: connectionId };
            await connectionService.replaceMetadata(connection, initialMetadata);
            await connectionService.replaceMetadata(connection, newMetadata);
            const dbConnection = await connectionService.getConnectionById(connectionId);
            const updatedMetadata = dbConnection?.metadata;
            expect(updatedMetadata).toEqual(newMetadata);
        });
        it('Should update metadata and not overwrite', async () => {
            const connections = await createConnectionSeeds();
            const initialMetadata = {
                name: 'test',
                host: 'test'
            };
            const newMetadata = {
                additionalName: 'test23'
            };
            const connectionId = connections[1];
            const dbConnection = (await connectionService.getConnectionById(connectionId));
            await connectionService.replaceMetadata(dbConnection, initialMetadata);
            await connectionService.updateMetadata(dbConnection, newMetadata);
            const updatedDbConnection = await connectionService.getConnectionById(connectionId);
            const updatedMetadata = updatedDbConnection?.metadata;
            expect(updatedMetadata).toEqual({ ...initialMetadata, ...newMetadata });
        });
    });
});
//# sourceMappingURL=connection.service.integration.test.js.map