import { vi, expect, describe, it, beforeEach } from 'vitest';
import axios from 'axios';
import environmentService from '../environment.service.js';
import WebhookService from './webhook.service.js';
vi.mock('axios', () => ({
    post: vi.fn()
}));
vi.mock('../environment.service.js', () => ({
    getById: vi.fn()
}));
describe('Webhook notification tests', () => {
    beforeEach(() => {
        // Reset mocks before each test
        vi.resetAllMocks();
    });
    /*
    it('Should not send a forward webhook if the webhook url is not present', async () => {});
    it('Should send a forwarded webhook if the webhook url is present', async () => {});
    it('Should not send an auth webhook if the webhook url is not present', async () => {});
    it('Should not send an auth webhook if the webhook url is not present even if the auth webhook is checked', async () => {});
    it('Should send an auth webhook if the webhook url is not and present if the auth webhook is checked', async () => {});
    it('Should not send an sync webhook if the webhook url is not present', async () => {});
    it('Should not send an sync webhook if the webhook url is not present even if always send is checked', async () => {});
    it('Should not send an sync webhook if the webhook url is present but if always send is not checked and there were no sync changes', async () => {});
    it('Should not send an sync webhook if the webhook url is present and if always send is checked and there were no sync changes', async () => {});
    it('Should send an sync webhook if the webhook url is present and if always send is checked and there were no sync changes', async () => {});
    it('Should send an sync webhook if the webhook url is present and if always send is not checked and there were sync changes', async () => {});
   */
    it('Should not send a forward webhook if the webhook url is not present', async () => {
        vi.mocked(environmentService.getById).mockResolvedValueOnce({ webhook_url: 'oo' });
        await WebhookService.forward(1, 'providerKey', 'provider', {}, {});
        expect(axios.post).not.toHaveBeenCalled();
    });
    it('Should send a forwarded webhook if the webhook url is present', async () => {
        vi.mocked(environmentService.getById).mockResolvedValueOnce({
            webhook_url: 'http://example.com/webhook',
            secret_key: 'secret'
        });
        await WebhookService.forward(1, 'providerKey', 'provider', {}, {});
        expect(axios.post).toHaveBeenCalled();
    });
    // More tests follow similar patterns...
    it('Should send an sync webhook if the webhook url is present and if always send is checked and there were no sync changes', async () => {
        vi.mocked(environmentService.getById).mockResolvedValueOnce({
            webhook_url: 'http://example.com/webhook',
            always_send_webhook: true,
            secret_key: 'secret'
        });
        const responseResults = { added: 0, updated: 0, deleted: 0 };
        await WebhookService.sendSyncUpdate({ environment_id: 1 }, 'syncName', 'model', responseResults, 'SYNC_TYPE', new Date(), 1, 1);
        expect(axios.post).toHaveBeenCalled();
    });
});
//# sourceMappingURL=webhook.service.unit.js.map