import { v2, client } from '@datadog/datadog-api-client';
import { isCloud } from './utils.js';
export var MetricTypes;
(function (MetricTypes) {
    MetricTypes["AUTH_TOKEN_REFRESH_START"] = "auth_token_refresh_start";
    MetricTypes["AUTH_TOKEN_REFRESH_SUCCESS"] = "auth_token_refresh_success";
    MetricTypes["AUTH_TOKEN_REFRESH_FAILURE"] = "auth_token_refresh_failure";
    MetricTypes["AUTH_TOKEN_REQUEST_START"] = "auth_token_request_start";
    MetricTypes["AUTH_TOKEN_REQUEST_CALLBACK_RECEIVED"] = "auth_token_request_callback_received";
    MetricTypes["AUTH_TOKEN_REQUEST_SUCCESS"] = "auth_token_request_success";
    MetricTypes["AUTH_TOKEN_REQUEST_FAILURE"] = "auth_token_request_failure";
    MetricTypes["SYNC_OVERLAP"] = "sync_overlap";
    MetricTypes["SYNC_FAILURE"] = "sync_failure";
    MetricTypes["SYNC_SUCCESS"] = "sync_success";
    MetricTypes["SYNC_SCRIPT_RETURN_USED"] = "sync_script_return_used";
    MetricTypes["GET_CONNECTION_FAILURE"] = "get_connection_failure";
    MetricTypes["GET_CONNECTION_SUCCESS"] = "get_connection_success";
    MetricTypes["SYNC_DEPLOY_SUCCESS"] = "sync_deploy_success";
    MetricTypes["SYNC_DEPLOY_FAILURE"] = "sync_deploy_failure";
    MetricTypes["SYNC_TRACK_RUNTIME"] = "sync_script_track_runtime";
    MetricTypes["SYNC_GET_RECORDS_OFFSET_USED"] = "sync_get_records_offset_used";
    MetricTypes["SYNC_GET_RECORDS_SORT_BY_USED"] = "sync_get_records_sort_by_used";
    MetricTypes["SYNC_GET_RECORDS_ORDER_USED"] = "sync_get_records_order_used";
    MetricTypes["SYNC_GET_RECORDS_INCLUDE_METADATA_USED"] = "sync_get_records_include_metadata_used";
    MetricTypes["SYNC_GET_RECORDS_DEPRECATED_METHOD_USED"] = "sync_get_records_deprecated_method_used";
    MetricTypes["SYNC_GET_RECORDS_QUERY_TIMEOUT"] = "sync_get_records_query_timeout";
    MetricTypes["FLOW_JOB_TIMEOUT_FAILURE"] = "flow_job_failure";
    MetricTypes["POST_CONNECTION_SCRIPT_FAILURE"] = "post_connection_script_failure";
    MetricTypes["WEBHOOK_TRACK_RUNTIME"] = "webhook_track_runtime";
    MetricTypes["INCOMING_WEBHOOK_RECEIVED"] = "incoming_webhook_received";
    MetricTypes["INCOMING_WEBHOOK_ISSUE_WRONG_CONNECTION_IDENTIFIER"] = "incoming_webhook_issue_wrong_connection_identifier";
    MetricTypes["INCOMING_WEBHOOK_ISSUE_CONNECTION_NOT_FOUND"] = "incoming_webhook_issue_connection_not_found";
    MetricTypes["INCOMING_WEBHOOK_ISSUE_WEBHOOK_SUBSCRIPTION_NOT_FOUND_REGISTERED"] = "incoming_webhook_issue_webhook_subscription_not_found_registered";
    MetricTypes["INCOMING_WEBHOOK_PROCESSED_SUCCESSFULLY"] = "incoming_webhook_processed_successfully";
    MetricTypes["INCOMING_WEBHOOK_FAILED_PROCESSING"] = "incoming_webhook_failed_processing";
})(MetricTypes || (MetricTypes = {}));
class MetricsManager {
    logInstance;
    metricsInstance;
    constructor() {
        try {
            if (isCloud() && process.env['DD_API_KEY'] && process.env['DD_APP_KEY']) {
                const configuration = client.createConfiguration();
                configuration.setServerVariables({
                    site: 'us3.datadoghq.com'
                });
                this.logInstance = new v2.LogsApi(configuration);
                this.metricsInstance = new v2.MetricsApi(configuration);
            }
        }
        catch (_) {
            return;
        }
    }
    async capture(eventId, message, operation, context = {}, additionalTags = '') {
        const params = {
            body: [
                {
                    ddsource: 'web',
                    ddtags: `${eventId}, environment:${process.env['NODE_ENV']}, ${additionalTags}`,
                    message,
                    service: operation,
                    additionalProperties: context
                }
            ]
        };
        await this.logInstance?.submitLog(params);
    }
    async captureMetric(metricName, metricId, metricCategory, value) {
        const currentTime = Math.floor(Date.now() / 1000);
        const params = {
            body: {
                series: [
                    {
                        metric: metricName,
                        points: [
                            {
                                timestamp: currentTime,
                                value
                            }
                        ],
                        unit: 'seconds',
                        resources: [
                            {
                                name: metricId,
                                type: metricCategory
                            }
                        ],
                        type: 3
                    }
                ]
            }
        };
        await this.metricsInstance?.submitMetrics(params);
    }
}
export default new MetricsManager();
//# sourceMappingURL=metrics.manager.js.map