/// <reference types="node" />
/// <reference types="node" />
import crypto from 'crypto';
import type { Config as ProviderConfig } from '../models/Provider';
import type { Environment } from '../models/Environment.js';
import type { EnvironmentVariable } from '../models/EnvironmentVariable.js';
import type { Connection, ApiConnection, StoredConnection } from '../models/Connection.js';
import type { RawDataRecordResult, DataRecord, DataRecordWithMetadata, RecordWrapCustomerFacingDataRecord, UnencryptedRawRecord } from '../models/Sync.js';
export declare const pbkdf2: (arg1: crypto.BinaryLike, arg2: crypto.BinaryLike, arg3: number, arg4: number, arg5: string) => Promise<Buffer>;
export declare const ENCRYPTION_KEY: string | undefined;
declare class EncryptionManager {
    private key;
    private algo;
    private encoding;
    private encryptionKeyByteLength;
    private keySalt;
    constructor(key: string | undefined);
    private shouldEncrypt;
    private encrypt;
    private decrypt;
    encryptEnvironment(environment: Environment): Environment;
    decryptEnvironment(environment: Environment | null): Environment | null;
    encryptApiConnection(connection: ApiConnection): StoredConnection;
    encryptConnection(connection: Connection): StoredConnection;
    decryptConnection(connection: StoredConnection | null): Connection | null;
    encryptEnvironmentVariables(environmentVariables: EnvironmentVariable[]): EnvironmentVariable[];
    decryptEnvironmentVariables(environmentVariables: EnvironmentVariable[] | null): EnvironmentVariable[] | null;
    encryptProviderConfig(config: ProviderConfig): ProviderConfig;
    decryptProviderConfig(config: ProviderConfig | null): ProviderConfig | null;
    encryptDataRecords(dataRecords: DataRecord[]): DataRecord[];
    decryptDataRecords(dataRecords: DataRecord[] | null, field?: string): DataRecordWithMetadata[] | RecordWrapCustomerFacingDataRecord | null;
    decryptDataRecord(dataRecord: RawDataRecordResult): UnencryptedRawRecord;
    encryptAllDataRecords(): Promise<void>;
    private saveDbConfig;
    private hashEncryptionKey;
    encryptDatabaseIfNeeded(): Promise<void>;
    private encryptDatabase;
}
declare const _default: EncryptionManager;
export default _default;
