import { v2, client } from '@datadog/datadog-api-client';
import { isCloud } from '@nangohq/utils/dist/environment/detection.js';
import tracer from 'dd-trace';
export var LogTypes;
(function (LogTypes) {
    LogTypes["AUTH_TOKEN_REFRESH_START"] = "auth_token_refresh_start";
    LogTypes["AUTH_TOKEN_REFRESH_SUCCESS"] = "auth_token_refresh_success";
    LogTypes["AUTH_TOKEN_REFRESH_FAILURE"] = "auth_token_refresh_failure";
    LogTypes["AUTH_TOKEN_REQUEST_START"] = "auth_token_request_start";
    LogTypes["AUTH_TOKEN_REQUEST_CALLBACK_RECEIVED"] = "auth_token_request_callback_received";
    LogTypes["AUTH_TOKEN_REQUEST_SUCCESS"] = "auth_token_request_success";
    LogTypes["AUTH_TOKEN_REQUEST_FAILURE"] = "auth_token_request_failure";
    LogTypes["ACTION_SUCCESS"] = "action_success";
    LogTypes["ACTION_FAILURE"] = "action_failure";
    LogTypes["SYNC_OVERLAP"] = "sync_overlap";
    LogTypes["SYNC_FAILURE"] = "sync_failure";
    LogTypes["SYNC_SUCCESS"] = "sync_success";
    LogTypes["SYNC_SCRIPT_RETURN_USED"] = "sync_script_return_used";
    LogTypes["GET_CONNECTION_FAILURE"] = "get_connection_failure";
    LogTypes["GET_CONNECTION_SUCCESS"] = "get_connection_success";
    LogTypes["SYNC_DEPLOY_SUCCESS"] = "sync_deploy_success";
    LogTypes["SYNC_DEPLOY_FAILURE"] = "sync_deploy_failure";
    LogTypes["SYNC_GET_RECORDS_OFFSET_USED"] = "sync_get_records_offset_used";
    LogTypes["SYNC_GET_RECORDS_SORT_BY_USED"] = "sync_get_records_sort_by_used";
    LogTypes["SYNC_GET_RECORDS_ORDER_USED"] = "sync_get_records_order_used";
    LogTypes["SYNC_GET_RECORDS_INCLUDE_METADATA_USED"] = "sync_get_records_include_metadata_used";
    LogTypes["SYNC_GET_RECORDS_DEPRECATED_METHOD_USED"] = "sync_get_records_deprecated_method_used";
    LogTypes["SYNC_GET_RECORDS_QUERY_TIMEOUT"] = "sync_get_records_query_timeout";
    LogTypes["FLOW_JOB_TIMEOUT_FAILURE"] = "flow_job_failure";
    LogTypes["POST_CONNECTION_SCRIPT_FAILURE"] = "post_connection_script_failure";
    LogTypes["INCOMING_WEBHOOK_RECEIVED"] = "incoming_webhook_received";
    LogTypes["INCOMING_WEBHOOK_ISSUE_WRONG_CONNECTION_IDENTIFIER"] = "incoming_webhook_issue_wrong_connection_identifier";
    LogTypes["INCOMING_WEBHOOK_ISSUE_CONNECTION_NOT_FOUND"] = "incoming_webhook_issue_connection_not_found";
    LogTypes["INCOMING_WEBHOOK_ISSUE_WEBHOOK_SUBSCRIPTION_NOT_FOUND_REGISTERED"] = "incoming_webhook_issue_webhook_subscription_not_found_registered";
    LogTypes["INCOMING_WEBHOOK_PROCESSED_SUCCESSFULLY"] = "incoming_webhook_processed_successfully";
    LogTypes["INCOMING_WEBHOOK_FAILED_PROCESSING"] = "incoming_webhook_failed_processing";
})(LogTypes || (LogTypes = {}));
export var MetricTypes;
(function (MetricTypes) {
    MetricTypes["ACTION_TRACK_RUNTIME"] = "action_track_runtime";
    MetricTypes["SYNC_TRACK_RUNTIME"] = "sync_script_track_runtime";
    MetricTypes["WEBHOOK_TRACK_RUNTIME"] = "webhook_track_runtime";
    MetricTypes["RUNNER_SDK"] = "nango.runner.sdk";
    MetricTypes["JOBS_CLEAN_ACTIVITY_LOGS"] = "nango.jobs.cron.cleanActivityLogs";
    MetricTypes["JOBS_DELETE_SYNCS_DATA"] = "nango.jobs.cron.deleteSyncsData";
    MetricTypes["JOBS_DELETE_SYNCS_DATA_JOBS"] = "nango.jobs.cron.deleteSyncsData.jobs";
    MetricTypes["JOBS_DELETE_SYNCS_DATA_SCHEDULES"] = "nango.jobs.cron.deleteSyncsData.schedules";
    MetricTypes["JOBS_DELETE_SYNCS_DATA_RECORDS"] = "nango.jobs.cron.deleteSyncsData.records";
    MetricTypes["JOBS_DELETE_SYNCS_DATA_DELETES"] = "nango.jobs.cron.deleteSyncsData.deletes";
    MetricTypes["PERSIST_RECORDS_COUNT"] = "nango.persist.records.count";
    MetricTypes["PERSIST_RECORDS_SIZE_IN_BYTES"] = "nango.persist.records.sizeInBytes";
    MetricTypes["AUTH_GET_ENV_BY_SECRET_KEY"] = "nango.auth.getEnvBySecretKey";
})(MetricTypes || (MetricTypes = {}));
export var SpanTypes;
(function (SpanTypes) {
    SpanTypes["CONNECTION_TEST"] = "nango.server.hooks.connectionTest";
    SpanTypes["JOBS_IDLE_DEMO"] = "nango.jobs.cron.idleDemos";
    SpanTypes["RUNNER_EXEC"] = "nango.runner.exec";
})(SpanTypes || (SpanTypes = {}));
class Telemetry {
    logInstance;
    constructor() {
        try {
            if (isCloud && process.env['DD_API_KEY'] && process.env['DD_APP_KEY']) {
                const configuration = client.createConfiguration();
                configuration.setServerVariables({
                    site: 'us3.datadoghq.com'
                });
                this.logInstance = new v2.LogsApi(configuration);
            }
        }
        catch (_) {
            return;
        }
    }
    async log(eventId, message, operation, context = {}, additionalTags = '') {
        const params = {
            body: [
                {
                    ddsource: 'web',
                    ddtags: `${eventId}, environment:${process.env['NODE_ENV']}, ${additionalTags}`,
                    message,
                    service: operation,
                    additionalProperties: context
                }
            ]
        };
        await this.logInstance?.submitLog(params);
    }
    increment(metricName, value) {
        tracer.dogstatsd.increment(metricName, value ?? 1);
    }
    decrement(metricName, value) {
        tracer.dogstatsd.decrement(metricName, value ?? 1);
    }
    duration(metricName, value) {
        tracer.dogstatsd.distribution(metricName, value);
    }
    time(metricName, func) {
        // eslint-disable-next-line @typescript-eslint/no-this-alias
        const that = this;
        const duration = (start) => {
            const durationComponents = process.hrtime(start);
            const seconds = durationComponents[0];
            const nanoseconds = durationComponents[1];
            const duration = seconds * 1000 + nanoseconds / 1e6;
            that.duration(metricName, duration);
        };
        // This function should handle both async/sync function
        // So it's try/catch regular execution and use .then() for async
        // @ts-expect-error can't fix this
        return function wrapped(...args) {
            const start = process.hrtime();
            try {
                const res = func(...args);
                if (res[Symbol.toStringTag] === 'Promise') {
                    return res.then((v) => {
                        duration(start);
                        return v;
                    }, (err) => {
                        duration(start);
                        throw err;
                    });
                }
                return res;
            }
            catch (err) {
                duration(start);
                throw err;
            }
        };
    }
}
export default new Telemetry();
//# sourceMappingURL=telemetry.js.map